==> haskell-special-values-0.1.0.0-302.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-3vVLF1K7hR6JT5ibkphtja
key:                  special-values-0.1.0.0-3vVLF1K7hR6JT5ibkphtja
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  89e5e3fe442524740c98801e554a62f1
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-9.6.6/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/special-values-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-special-values
hs-libraries:         HSspecial-values-0.1.0.0-3vVLF1K7hR6JT5ibkphtja
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    ieee754-0.8.0-EGVgNa4vggOEmRT3C9pqtp
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-special-values-0.1.0.0-303-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-3ZUGlBsAmm8HjDondbWfOD
key:                  special-values-0.1.0.0-3ZUGlBsAmm8HjDondbWfOD
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  ce24f8540aab38f0bccd087e644da5ac
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-9.6.6/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/special-values-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-special-values
hs-libraries:         HSspecial-values-0.1.0.0-3ZUGlBsAmm8HjDondbWfOD
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    ieee754-0.8.0-EGVgNa4vggOEmRT3C9pqtp
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
